@@ -10,7 +10,7 @@ Ais25::Ais25(const char *nmea_payload, const size_t pad) {
     const size_t num_bits = strlen(nmea_payload) * 6 - pad;
     if (num_bits < 40 || num_bits > 168) { status = AIS_ERR_BAD_BIT_COUNT; return; }
 
-    std::bitset<168> bs;
+    bitset<168> bs;
     status = aivdm_to_bits(bs, nmea_payload);
     if (had_error()) return;
 
